@@ -47,6 +47,11 @@ test_that("formats work", {
     paste(values[1])
   )
 
+  expect_identical(
+    format_value(values[1], format = "xx"),
+    format_value(values[1], format = "default")
+  )
+
   expect_identical(
     format_value(values[1], format = "xx."),
     "5"
@@ -349,8 +354,20 @@ test_that("formats work", {
     "3456 / 10000 (34.56%)"
   )
 
+  expect_identical(
+    format_value(ndfvals, "xx"),
+    format_value(ndfvals, "default")
+  )
+
+  expect_identical(
+    format_value(values, "xx"),
+    format_value(values, "default")
+  )
+
   expect_identical(format_value(NULL, "xx"), "")
 
+  expect_identical(format_value(NULL, "default"), "")
+
   expect_identical(
     format_value(5.123, "xx.x", output = "html"),
     list("5.1" = htmltools::tagList(format_value(5.123, "xx.x"), NULL))
@@ -392,6 +409,16 @@ test_that("formats work", {
     c("1", "NA")
   )
 
+  expect_equal(
+    format_value(NA, "default", na_str = "-"),
+    "-"
+  )
+
+  expect_equal(
+    format_value(c(1, NA), "default"),
+    c("1", "NA")
+  )
+
   ## trailing 0s are correct
   expect_identical(format_value(0, "xx."), "0")
   expect_identical(format_value(0, "xx.x"), "0.0")
@@ -835,6 +862,7 @@ test_that("Decimal alignment: a specific case with larger widths", {
 test_that("All supported 1d format cases of decimal alignment", {
   hard_c_formats <- list_valid_format_labels()$`1d`
   hard_c <- sapply(hard_c_formats, gsub, pattern = "x", replacement = "1")
+  hard_c["default"] <- hard_c["xx"]
   lhc <- length(hard_c)
   reduced_df <- mtcars[seq_len(lhc), c(1, 6, 7)]
   rownames(reduced_df) <- letters[seq_len(lhc)]
@@ -877,7 +905,8 @@ test_that("All supported 1d format cases of decimal alignment", {
     "m        N=11                              N=11     right  ",
     "n        >999.9           >999.9                  dec_left ",
     "o        >999.99          >999.99                 dec_left ",
-    "p   1.1111 | (<0.0001)     1.1111 | (<0.0001)       right  "
+    "p   1.1111 | (<0.0001)     1.1111 | (<0.0001)       right  ",
+    "q          11            11                         left   "
   )
   expect_identical(res_dec, expected)
 })
@@ -1016,6 +1045,22 @@ test_that("sas-style rounding works", {
     "7.85"
   )
 
+  expect_identical(
+    format_value(-0.001, "xx.xx", round_type = "iec"),
+    "-0.00"
+  )
+
+  expect_identical(
+    format_value(-0.001, "xx.xx", round_type = "sas"),
+    "0.00"
+  )
+
+  expect_identical(
+    format_value(-0.001, "xx.xx", round_type = "iec_mod"),
+    "0.00"
+  )
+
+
   forms <- list_valid_format_labels()
   for (fmtset in 1:3) {
     for (digs in 0:3) {
@@ -1071,3 +1116,43 @@ test_that("na_str works when having multiple NAs and multiple values to be chang
     "a (1.0 - b)"
   )
 })
+
+test_that("Methods for obj_round_type", {
+  inputdf <- mtcars
+  obj_format(inputdf$wt) <- "xx.xx"
+  dfmf <- basic_matrix_form(inputdf)
+  dfmf2 <- basic_matrix_form(inputdf, round_type = "sas")
+
+  expect_identical(obj_round_type(dfmf), "iec")
+  expect_identical(obj_round_type(dfmf2), "sas")
+
+  # check actual rounding
+  df_iec <- dfmf$strings[1 + seq_len(nrow(inputdf)), "wt"]
+  df_sas <- dfmf2$strings[1 + seq_len(nrow(inputdf)), "wt"]
+
+  fmt_iec <- sapply(inputdf[, "wt"], function(x) format_value(x, format = "xx.xx", round_type = "iec"))
+  fmt_sas <- sapply(inputdf[, "wt"], function(x) format_value(x, format = "xx.xx", round_type = "sas"))
+  expect_identical(df_iec, fmt_iec)
+  expect_identical(df_sas, fmt_sas)
+})
+
+test_that("Methods for obj_round_type on list object", {
+  inputdf <- mtcars
+  obj_format(inputdf$wt) <- "xx.xx"
+
+  bmf <- basic_matrix_form(inputdf, round_type = "sas")
+  blmf <- basic_listing_mf(inputdf, keycols = c("vs", "gear"), round_type = "sas")
+  l_mf <- list(bmf, blmf)
+
+  expect_identical(obj_round_type(l_mf), "sas")
+
+  # test setter
+  # current object is list of MatrixPrintForm class, round_type cannot not be updated here
+  # as rounding occurs during creation of MatrixPrintForm object
+  l_mf_iec <- l_mf
+  expect_error(
+    obj_round_type(l_mf_iec) <- "iec",
+    "Cannot alter round type on a `MatrixPrintForm` object"
+  )
+  # test of setter for list of listing_obj will be included in rlistings instead
+})
